@@ -16,19 +16,32 @@
 #define ZX_USE_UTF8 1
 #include <ZXing/BarcodeFormat.h>
 #include <ZXing/ReadBarcode.h>
-#include <ZXing/Result.h>
 
 using namespace Prison;
 
+#if KZXING_VERSION < QT_VERSION_CHECK(2, 3, 0)
 ZXing::Result ImageScanner::readBarcode(const QImage &image, Format::BarcodeFormats formats)
+#else
+ZXing::Barcode ImageScanner::readBarcode(const QImage &image, Format::BarcodeFormats formats)
+#endif
 {
+#if KZXING_VERSION < QT_VERSION_CHECK(2, 3, 0)
     ZXing::DecodeHints hints;
-    hints.setFormats(formats == Format::NoFormat ? ZXing::BarcodeFormats::all() : Format::toZXing(formats));
+#else
+    ZXing::ReaderOptions hints;
+#endif
+    if (formats != Format::NoFormat) {
+        hints.setFormats(Format::toZXing(formats));
+#if KZXING_VERSION < QT_VERSION_CHECK(3, 0, 0)
+    } else {
+        hints.setFormats(ZXing::BarcodeFormats::all());
+#endif
+    }
 
     // handle formats ZXing supports directly
     switch (image.format()) {
     case QImage::Format_Invalid:
-#if ZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
+#if KZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
         return ZXing::Result(ZXing::DecodeStatus::FormatError);
 #else
         return {};
@@ -40,7 +53,11 @@ ZXing::Result ImageScanner::readBarcode(const QImage &image, Format::BarcodeForm
     case QImage::Format_RGB32:
     case QImage::Format_ARGB32:
     case QImage::Format_ARGB32_Premultiplied:
+#if KZXING_VERSION < QT_VERSION_CHECK(2, 3, 0)
         return ZXing::ReadBarcode({image.bits(), image.width(), image.height(), ZXing::ImageFormat::XRGB, (int)image.bytesPerLine()}, hints);
+#else
+        return ZXing::ReadBarcode({image.bits(), image.width(), image.height(), ZXing::ImageFormat::ARGB, (int)image.bytesPerLine()}, hints);
+#endif
     case QImage::Format_RGB16:
     case QImage::Format_ARGB8565_Premultiplied:
     case QImage::Format_RGB666:
@@ -56,14 +73,18 @@ ZXing::Result ImageScanner::readBarcode(const QImage &image, Format::BarcodeForm
     case QImage::Format_RGBX8888:
     case QImage::Format_RGBA8888:
     case QImage::Format_RGBA8888_Premultiplied:
+#if KZXING_VERSION < QT_VERSION_CHECK(2, 3, 0)
         return ZXing::ReadBarcode({image.bits(), image.width(), image.height(), ZXing::ImageFormat::RGBX, (int)image.bytesPerLine()}, hints);
+#else
+        return ZXing::ReadBarcode({image.bits(), image.width(), image.height(), ZXing::ImageFormat::RGBA, (int)image.bytesPerLine()}, hints);
+#endif
     case QImage::Format_BGR30:
     case QImage::Format_A2BGR30_Premultiplied:
     case QImage::Format_RGB30:
     case QImage::Format_A2RGB30_Premultiplied:
         break; // needs conversion
     case QImage::Format_Alpha8:
-#if ZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
+#if KZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
         return ZXing::Result(ZXing::DecodeStatus::FormatError);
 #else
         return {};
@@ -84,10 +105,11 @@ ZXing::Result ImageScanner::readBarcode(const QImage &image, Format::BarcodeForm
     case QImage::Format_RGBX32FPx4:
     case QImage::Format_RGBA32FPx4:
     case QImage::Format_RGBA32FPx4_Premultiplied:
+    case QImage::Format_CMYK8888:
         break; // needs conversion
 
     case QImage::NImageFormats: // silence warnings
-#if ZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
+#if KZXING_VERSION < QT_VERSION_CHECK(1, 4, 0)
         return ZXing::Result(ZXing::DecodeStatus::FormatError);
 #else
         return {};
